@@ -240,9 +240,21 @@ test_readGT <- function()
     fl <- system.file("unitTests", "cases", "no_INFO_header.vcf", 
                       package="VariantAnnotation")
     GT <- readGT(fl, nucleotides=TRUE)
-    checkIdentical(unname(GT[,1]), rep(".", 5))
+    checkIdentical(unname(GT[,1]), rep("./.", 5))
     ## genotypeCodesToNucleotides
     vcf0 <- readVcf(fl, "")
     vcf1 <- genotypeCodesToNucleotides(vcf0)
     checkIdentical(GT, geno(vcf1)$GT)
 }
+
+test_buffer_realloc <- function()
+{
+    fl <- system.file("unitTests", "cases", "buffer_realloc.vcf",
+                      package="VariantAnnotation")
+    vcf <- readVcf(fl)
+    target <- c("gridss9_272646b", "gridss9_31852o")
+    checkIdentical(target, names(vcf))
+
+    target <- ".GGGGGGGGG"
+    checkIdentical(target, alt(vcf)[[1]])
+}
